eegdash.paths
=============

.. automodule:: eegdash.paths
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   
   .. rubric:: Functions

   .. autosummary::
   
      get_default_cache_dir
   
